"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _server = require("../server");

var _extendRes = _interopRequireDefault(require("../server/lib/extend-res"));

var _cookie = require("../server/lib/cookie");

async function NextAuthNextHandler(req, res, userOptions) {
  (0, _extendRes.default)(req, res);
  const request = {
    body: req.body,
    query: req.query,
    cookies: req.cookies,
    headers: req.headers,
    method: req.method
  };
  const {
    json,
    redirect,
    text,
    cookies,
    headers,
    status = 200
  } = await (0, _server.NextAuthHandler)({ ...request,
    userOptions
  });
  res.status(status);
  cookies === null || cookies === void 0 ? void 0 : cookies.forEach(cookie => {
    (0, _cookie.set)(res, cookie.name, cookie.value, cookie.options);
  });
  headers === null || headers === void 0 ? void 0 : headers.forEach(header => {
    res.setHeader(header.key, header.value);
  });

  if (redirect) {
    return res.redirect(redirect);
  } else if (json) {
    return res.json(json);
  } else if (text) {
    return res.send(text);
  }

  return res.status(400).send(`Error: HTTP ${req.method} is not supported for ${req.url}`);
}

function NextAuth(...args) {
  if (args.length === 1) {
    return async (req, res) => await NextAuthNextHandler(req, res, args[0]);
  }

  return NextAuthNextHandler(args[0], args[1], args[2]);
}

var _default = NextAuth;
exports.default = _default;